import Vue from "vue";
import Router from "vue-router";

Vue.use(Router);

/* Layout */
import Layout from "@/layout";

/**
 * Note: sub-menu only appear when route children.length >= 1
 * Detail see: https://panjiachen.github.io/vue-element-admin-site/guide/essentials/router-and-nav.html
 *
 * hidden: true                   if set true, item will not show in the sidebar(default is false)
 * alwaysShow: true               if set true, will always show the root menu
 *                                if not set alwaysShow, when item has more than one children route,
 *                                it will becomes nested mode, otherwise not show the root menu
 * redirect: noRedirect           if set noRedirect will no redirect in the breadcrumb
 * name:'router-name'             the name is used by <keep-alive> (must set!!!)
 * meta : {
    roles: ['admin','editor']    control the page roles (you can set multiple roles)
    title: 'title'               the name show in sidebar and breadcrumb (recommend set)
    icon: 'svg-name'/'el-icon-x' the icon show in the sidebar
    breadcrumb: false            if set false, the item will hidden in breadcrumb(default is true)
    activeMenu: '/example/list'  if set path, the sidebar will highlight the path you set
  }
 */
// 1、管理员；2、省级总帐号；3、升级；4、市级；5、区级（普通账号）；99、企业(楼宇）
/**
 * constantRoutes
 * a base page that does not have permission requirements
 * all roles can be accessed
 */
export const constantRoutes = [
  {
    path: "/login",
    component: () => import("@/views/login/index"),
    hidden: true,
  },

  {
    path: "/404",
    component: () => import("@/views/404"),
    hidden: true,
  },
  // {
  //   path: "/",
  //   component: Layout,
  //   redirect: "/index",
  //   children: [
  //     {
  //       path: "index",
  //       name: "主页",
  //       component: () => import("@/views/dashboard/index"),
  //       meta: { title: "主页", role: [1, 2, 3, 4, 5], icon: "el-icon-s-home" },
  //     },
  //   ],
  // },

  {
    path: "/user",
    component: Layout,
    children: [
      {
        path: "index",
        name: "user_manage",
        component: () => import("@/views/user_manage/index"),
        meta: { title: "账号管理", role: [1, 2], icon: "el-icon-menu" },
      },
    ],
  },
  {
    path: "/area",
    component: Layout,
    children: [
      {
        path: "index",
        name: "area_manage",
        component: () => import("@/views/area/index"),
        meta: {
          title: "区域名称列表",
          role: [5],
          icon: "el-icon-map-location",
        },
      },
    ],
  },
  {
    path: "/machine_list",
    component: Layout,
    meta: { title: "设备管理", role: [1, 2, 3, 4, 5, 99], icon: "el-icon-cpu" },
    children: [
      {
        path: "index",
        name: "machine_list",
        component: () => import("@/views/machine_list/index"),
        meta: {
          title: "设备列表",
          role: [1, 2, 3, 4, 5, 99],
          icon: "el-icon-notebook-2",
        },
      },
      {
        path: "logo",
        name: "logo_manage",
        component: () => import("@/views/logo_manage/index"),
        meta: {
          title: "logo配置",
          role: [1, 2],
          icon: "el-icon-picture-outline-round",
        },
      },
    ],
  },
  {
    path: "/pass_records",
    component: Layout,
    children: [
      {
        path: "index",
        name: "pass_records",
        component: () => import("@/views/pass_records/index"),
        meta: {
          title: "进出记录",
          role: [1, 2, 3, 4, 5, 99],
          icon: "el-icon-date",
        },
      },
    ],
  },
  {
    path: "/basic_setup",
    component: Layout,
    redirect: "/basic_setup/index",
    name: "basic_setup",
    meta: { title: "基本设置", role: [5, 99], icon: "el-icon-setting" },
    children: [
      {
        path: "index",
        name: "index",
        component: () => import("@/views/basic_setup/index"),
        meta: { title: "基本设置", role: [5, 99], icon: "el-icon-setting" },
      },
      {
        path: "edit",
        name: "edit",
        hidden: true,
        component: () => import("@/views/basic_setup/edit"),
        meta: { title: "梯控关系表", role: [5, 99] },
      },
    ],
  },
  // 404 page must be placed at the end !!!
  { path: "*", redirect: "/404", hidden: true },
];

const createRouter = () =>
  new Router({
    // mode: 'history', // require service support
    scrollBehavior: () => ({ y: 0 }),
    routes: constantRoutes,
  });

const router = createRouter();

// Detail see: https://github.com/vuejs/vue-router/issues/1234#issuecomment-357941465
export function resetRouter() {
  const newRouter = createRouter();
  router.matcher = newRouter.matcher; // reset router
}

export default router;
